************************************************************************
* This file is part of OpenMolcas.                                     *
*                                                                      *
* OpenMolcas is free software; you can redistribute it and/or modify   *
* it under the terms of the GNU Lesser General Public License, v. 2.1. *
* OpenMolcas is distributed in the hope that it will be useful, but it *
* is provided "as is" and without any express or implied warranties.   *
* For more details see the full text of the license in the file        *
* LICENSE or in <http://www.gnu.org/licenses/>.                        *
************************************************************************
      Subroutine P_Mem(
#define _CALLING_
#include "mem_interface.fh"
     &)
#include "mem_interface.fh"
*
      Mem=1
*
      Return
c Avoid unused argument warnings
      If (.False.) Then
         Call Unused_integer(nHer)
         Call Unused_integer(la)
         Call Unused_integer(lb)
         Call Unused_integer(lr)
      End If
      End
